@@ -82,28 +82,48 @@ class PyJoke:
         return ((n_keywords*100)+n_occurenc+ratio*10)*float(weight)
 
 
+
     ###############################################
     ##    getJoke
     ##    Input:     A list of Keywords
     ##    Output:    2nd best joke
     ###############################################
     def getJoke(self,keyw):
+        # - - - - - - - - - - - - - - - - - - - - - - - -
+        def queryCompare(field,word):
+            if self.params.database=="sqlite" and not self.params.nao:
+                return "`"+field+"` REGEXP  \'"+word+"\'"
+            else:
+                return "`"+field+"` LIKE  \'%"+word+"%\'"
+        # - - - - - - - - - - - - - - - - - - - - - - - -
 
         jokes = {}
 
-
         ##    QUERY
         #################################
-        if self.params.database=="sqlite" and not self.params.nao:
-            query = "SELECT text FROM "+self.params.table+" WHERE LENGTH(`text`)<"+str(self.params.jokelen)+" AND (`text` REGEXP  \'"+keyw.getWord(0)+"\'";
-            for x in range(1,len(keyw)):
-                query = query + " OR  `text` REGEXP  \'"+keyw.getWord(x)+"\'";
-            query = query + ") ORDER BY score DESC "
-        else:
-            query = "SELECT text FROM "+self.params.table+" WHERE LENGTH(`text`)<"+str(self.params.jokelen)+" AND (`text` LIKE  \'%"+keyw.getWord(0)+"%\'";
-            for x in range(1,len(keyw)):
-                query = query + " OR  `text` LIKE  \'%"+keyw.getWord(x)+"%\'";
-            query = query + ") ORDER BY score DESC "
+
+        # SELECT text FROM table WHERE length...
+        query = "SELECT text FROM "+self.params.table+" WHERE LENGTH(`text`)<"+\
+        str(self.params.jokelen)
+        # ...AND (text IS firstkeyword ...
+        query = query + " AND ( "+queryCompare("text",keyw.getWord(0))
+        if self.params.usekeywords:
+            query = query + " OR "+queryCompare("keywords",keyw.getWord(0))
+
+        # For all keywords after the first one
+        for x in range(1,len(keyw)):
+            # ...OR text IS keyword...
+            query = query + " OR "+queryCompare("text",keyw.getWord(x))
+            # ...OR keyword IS keyword...
+            if self.params.usekeywords:
+                query = query + " OR "+queryCompare("keywords",keyw.getWord(x))
+
+        # ... order by score (why?)
+        query = query + ") ORDER BY score DESC "
+
+
+        if self.params.debug:
+            print "Query:"+query
 
         ##    Connection to Database
         #################################
@@ -179,18 +199,6 @@ class PyJoke:
         self.params = Parameters()
 
     def getTheJoke(self, sentence):
-        # Conversation
-        if self.params.conv!=0:
-            for i in range(self.params.conv):
-                keyw = KeywordsList(sentence,self.params)
-                print "[PyJoke - sentence {}] {}".format(i+1,sentence)
-                answer = self.getJoke(keyw)
-                print "[PyJoke - joke      ] "+answer+"\n"
-                sentence = answer.encode('utf-8')
-
-                return "Désactivez le mode conversation"
-        # Single output
-        else:
             keyw = KeywordsList(sentence,self.params)
             #print len(keyw)
             return self.getJoke(keyw).encode('utf-8')
